import os
import sys

from sqlalchemy import create_engine
from sqlalchemy.orm import sessionmaker
Session = sessionmaker()

from phildb import constants
from phildb import dbstructures
from phildb.exceptions import AlreadyExistsError

def create(tsdb_path):

    if not os.path.exists(tsdb_path):
        os.makedirs(tsdb_path)
        os.makedirs(os.path.join(tsdb_path, 'data'))
    elif not os.listdir(tsdb_path):
        os.makedirs(os.path.join(tsdb_path, 'data'))
    else:
        raise AlreadyExistsError('PhilDB database already exists at: {0}'.format(tsdb_path))

    engine = create_engine('sqlite:///{0}{1}{2}'.format(tsdb_path, os.path.sep, constants.METADATA_DB))
    dbstructures.Base.metadata.create_all(engine)

    Session.configure(bind=engine)
    session = Session()

    version = dbstructures.SchemaVersion(version=constants.DB_VERSION)
    session.add(version)
    session.commit()

if __name__ == "__main__":
    create(sys.argv[1])




import argparse
from datetime import datetime, date
import sys

import numpy as np
import pandas as pd
from matplotlib import pyplot as plt

from IPython.terminal.embed import InteractiveShellEmbed
ipshell = InteractiveShellEmbed()

from phildb import __version__
from phildb.database import PhilDB

def main():
    parser = argparse.ArgumentParser(description='Open PhilDB database.')
    parser.add_argument('dbname', help="PhilDB database to open", nargs='?')
    parser.add_argument('--version', action='store_true', help="Print version and exit.")

    args = parser.parse_args()

    if args.version:
        print("PhilDB version: {0}".format(__version__))
        exit()

    if args.dbname is None:
        print(parser.print_help())
        exit()

    db = PhilDB(args.dbname)
    ipshell("Running timeseries database: {0}\n"
            "Access the 'db' object to operate on the database.\n"
            "\n"
            "Run db.help() for a list of available commands.".format(db)
        )

if __name__ == "__main__":
    main()



import calendar
from struct import unpack, calcsize
import numpy as np
import pandas as pd
import os

from phildb.constants import METADATA_MISSING_VALUE
from phildb.log_handler import LogHandler

def __read(filename):
    field_names = ['date', 'value', 'metaID']
    entry_format = 'ldi' # long, double, int; See field names above.
    entry_size = calcsize(entry_format)

    records = np.fromfile(filename, dtype=np.dtype({'names':field_names, 'formats': entry_format}))

    if records == []: return pd.DataFrame(None, columns = ['date', 'value', 'metaID'])

    df = pd.DataFrame(records, columns = field_names)
    df['date'] = pd.to_datetime(df['date'], unit='s')
    df = df.set_index('date')

    meta_ids = df.metaID
    df.loc[df.metaID == METADATA_MISSING_VALUE] = np.nan
    df.metaID = meta_ids

    return df

def read(filename):
    return __read(filename).value

def read_log(log_file, as_at_datetime):

    with LogHandler(log_file, 'r') as reader:
        df = reader.read(calendar.timegm(as_at_datetime.utctimetuple()))

    return df.value
